From: Dr. Stephen Henson <steve@openssl.org>
Date: Tue, 5 Jan 2010 17:33:20 +0000 (+0000)
Subject: PR: 2132
X-Git-Tag: OpenSSL_0_9_8m-beta1~21
X-Git-Url: https://git.librecmc.org/?a=commitdiff_plain;h=309aa5fbf3d8654e31a56f6d58da41f1ed4cdd94;p=oweals%2Fopenssl.git

PR: 2132
Submitted by: steve

Fix bundled pod2man.pl to handle alternative comment formats.
---

diff --git a/util/pod2man.pl b/util/pod2man.pl
index 546d1ec186..025d914f2e 100755
--- a/util/pod2man.pl
+++ b/util/pod2man.pl
@@ -425,7 +425,7 @@ if ($name ne 'something') {
 	    }
 	    next if /^=cut\b/;	# DB_File and Net::Ping have =cut before NAME
 	    next if /^=pod\b/;  # It is OK to have =pod before NAME
-	    next if /^=for\s+comment\b/;  # It is OK to have =for comment before NAME
+	    next if /^=(for|begin|end)\s+comment\b/;  # It is OK to have =for =begin or =end comment before NAME
 	    die "$0: Invalid man page - 1st pod line is not NAME in $ARGV[0]\n" unless $lax;
 	}
 	die "$0: Invalid man page - no documentation in $ARGV[0]\n" unless $lax;